@@ -8,7 +8,7 @@ import os,sys
 # Stupid packaging messes with paths...
 SCRIPT_DIR = os.path.dirname(os.path.abspath(__file__))
 print("SCRIPT_DIR=",SCRIPT_DIR)
-sys.append(SCRIPT_DIR)
+sys.path.append(SCRIPT_DIR)
 
 from ScrollText import *
 from TerminalWindow import *
